import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.sql.Blob;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.imageio.ImageIO;

public class Fachada {
	private PreparedStatement getPaciente;
	private PreparedStatement setPaciente;

	private String nome;
	private BufferedImage foto;
	private Connection con;
	public Fachada() throws SQLException, ClassNotFoundException {
		con = Conexao_Oracle.getConnection();
		this.getPaciente = con.prepareStatement("SELECT P.nome, P.foto "
				+ "FROM Paciente P WHERE cpf_paciente=?");
		this.setPaciente = con.prepareStatement("UPDATE Paciente SET foto=?"
				+ "WHERE cpf_paciente=?");
	}

	public void fazConsulta(String cpf) throws SQLException, IOException{
		this.getPaciente.setString(1, cpf);
		ResultSet rs = this.getPaciente.executeQuery();
		rs.next();
		this.nome = rs.getString("nome");
		Blob b = rs.getBlob("foto");

		if (b != null) {
			this.foto = ImageIO.read(b.getBinaryStream());
		} else {
			this.foto = null;
		}
		rs.close();

	}

	public void atualizaImagem(File img, String cpf) throws IOException,
			SQLException {
		if (img.length() != 0) {
			FileInputStream fis = new FileInputStream(img);
			this.setPaciente.setString(2, cpf);
			this.setPaciente.setBinaryStream(1, fis, (int) img.length());
			this.setPaciente.execute();
			fis.close();
		} else {
			throw new IOException("Arquivo nao encontrado");
		}
	}
	public void close() throws SQLException{
		this.con.close();
		this.setPaciente.close();
		this.getPaciente.close();
	}
	public String getNome() {
		return this.nome;
	}

	public BufferedImage getFoto() {
		return this.foto;
	}

//	public static void main(String[] args) throws SQLException, IOException {
//		Fachada f = new Fachada();
//		f.fazConsulta("72579047978");
//		//f.atualizaImagem("foto1.jpg", "72579047978");
//		System.out.println(f.getNome());
//		System.out.println(f.getFoto());
//		f.close();
//
//	}

}
